Phys. Rev. Lett. 122, 145901 (2019) - Phonon Magnetochiral Effect
Description: A chiral material exposed to a magnetic field allows phonons to travel faster in one direction than another, an effect that might be used to create an acoustic diode.
Date: 2019-04-10

- Featured in Physics
- Editors' Suggestion

### Phonon Magnetochiral Effect

##### T. Nomura, X.-X. Zhang, S. Zherlitsyn, J. Wosnitza, Y. Tokura, N. Nagaosa, and S. Seki

##### Phys. Rev. Lett. 122, 145901 – Published 10 April 2019

###### See Viewpoint: Phonons Hum a Magnetochiral Tune

More
×

- Article
- References
- Citing Articles (64)
- Supplemental Material

PDF HTML Export Citation

  Abstract
  Physics News and Commentary
  Authors
  Article Text

- ACKNOWLEDGMENTS

  Supplemental Material
  References

#### Abstract

The magnetochiral effect (MCE) of phonons, a nonreciprocal acoustic propagation arising due to symmetry principles, is demonstrated in the chiral-lattice ferrimagnet Cu 2 OSeO 3. Our high-resolution ultrasound experiments reveal that the sound velocity differs for parallel and antiparallel propagation with respect to the external magnetic field. The sign of the nonreciprocity depends on the chirality of the crystal in accordance with the selection rule of the MCE. The nonreciprocity is enhanced below the magnetic ordering temperature and at higher ultrasound frequencies, which is quantitatively explained by a proposed magnon-phonon hybridization mechanism.

- Received 26 September 2018

DOI: https://doi.org/10.1103/PhysRevLett.122.145901

© 2019 American Physical Society

#### Physics Subject Headings (PhySH)

Acoustic phonons Magnetoelastic effect
Chiral magnets Noncentrosymmetric materials
Path-integral methods Ultrasound techniques
Condensed Matter, Materials & Applied Physics

#### Viewpoint

#### Phonons Hum a Magnetochiral Tune

###### Published 10 April 2019

A chiral material exposed to a magnetic field allows phonons to travel faster in one direction than another, an effect that might be used to create an acoustic diode.

See more in Physics

Click to Expand

#### Authors & Affiliations

T. Nomura1,*, X.-X. Zhang2,3,*, S. Zherlitsyn1, J. Wosnitza1,4, Y. Tokura2,5, N. Nagaosa2,5, and S. Seki2,5,6

- 1Hochfeld-Magnetlabor Dresden (HLD-EMFL), Helmholtz-Zentrum Dresden-Rossendorf, 01328 Dresden, Germany
- 2Department of Applied Physics, The University of Tokyo, Tokyo 113-8656, Japan
- 3Quantum Matter Institute, University of British Columbia, Vancouver BC V6T 1Z4, Canada
- 4Institut für Festkörper-und Materialphysik, TU-Dresden, 01062 Dresden, Germany
- 5RIKEN Center for Emergent Matter Science (CEMS), Wako 351-0198, Japan
- 6Institute of Engineering Innovation, The University of Tokyo, Tokyo 113-8656, Japan

- *These two authors contributed equally

Click to Expand

#### Article Text (Subscription Required)

Click to Expand

#### Supplemental Material (Subscription Required)

Click to Expand

#### References (Subscription Required)

Click to Expand

##### Issue

Vol. 122, Iss. 14 — 12 April 2019

Reuse & Permissions

##### Access Options

- Buy Article »
- Log in with individual APS Journal Account »
- Log in with a username/password provided by your institution »
- Get access through a U.S. public or high school library »

Article Available via CHORUS

Download Accepted Manuscript

#### Authorization Required

Log In

###### Other Options

- Buy Article »
- Find an Institution with the Article »

×

#### Download & Share

PDF Export Reuse & Permissions Citing Articles (64)

- Tweet

×

#### Images

- ###### Figure 1

  Experimental configurations to examine the phonon MCE. Chirality of the crystal (σ=±1), sound propagation direction (±k), and magnetic field direction (±H) are successively inverted and the relative sound velocities are compared. The L- and D-type crystal structures of Cu 2 OSeO 3 are shown along the [111] direction, where the spheres represent Cu (blue), O (red), and Se (green) atoms.

  Reuse & Permissions

- ###### Figure 2

  (a)–(c) Relative changes of the sound velocity Δ v/v 0 as a function of magnetic field H at 2 K. The transverse (c 11−c 12)/2 mode (k∥H∥[110], u∥[1 1¯0]) for the (a) L and (b) D crystal, and (c) the longitudinal (c 11+c 12+2 c 44)/2 mode (k∥u∥H∥[110]) for the D crystal are presented. The sound propagation direction (±k) and the ultrasound frequency are denoted for each curve. All the experimental results are shown for up and down field sweeps. The sound velocities for the transverse and longitudinal modes are v(c 11−c 12)/2=2.3 km/s and v(c 11+c 12+2 c 44)/2=4.1 km/s, respectively. (d) Δ v/v 0 as a function of |H| for the transverse mode at 710 MHz with +k in the L crystal. The results for H>0 (H<0) are shown by cyan (magenta). (e) Magnitude of the MCE g MC as a function of |H|, which corresponds to the difference between the data for +H and −H in Fig. 2. (f) Maximum magnitude of the MCE g MC(H c 2) at 2 K as a function of ultrasound frequency for the transverse mode. The results are shown for σ=±1 and ±k. The black dotted curves [Figs. 2 and 2] denote the calculated results based on Eq. (2) with the magnetoelastic coupling constant γ=90.

  Reuse & Permissions

- ###### Figure 3

  Temperature dependencies of (a) g MC(H c 2) and of (b) the relative change of the sound velocity at H c 2 for the transverse mode. (c) Contour plot of g MC mapped on the T−H phase diagram. The phase boundaries are determined by the anomalies in Δ v/v 0 (triangles and squares). Here, the results for the L crystal at 710 MHz are used.

  Reuse & Permissions

- ###### Figure 4

  (a) Magnetoelastic coupling due to the shear strain. TA phonons cause the displacements u x, y of the neighboring lattice sites (blue circles) from the original places (dotted circles). The original DM vector D→z is modified to D→z′ by a tilting angle β. The magnetic moments (dashed and red arrows) and the TA phonon propagation are along the z^ direction. In reality, the two displacements are not necessarily in the same direction. (b) Dispersions of the magnon and phonon bands hybridized by the chiral magnetoelastic coupling. The original dispersions are shown by dotted lines. One of the circularly polarized phonon mode hybridizes with the magnons, leading to the anticrossing. Another mode does not hybridize and its dispersion remains as the original blue dotted line. The ultrasound frequency used in this study (dashed line) was always lower than the hybridization frequency.

  Reuse & Permissions

×

Sign up to receive regular email alerts from Physical Review Letters

#### Log In

Cancel

- Forgot your username/password?
- Create an account

×

#### Search

#### Article Lookup

###### Paste a citation or DOI

###### Enter a citation

Journal:
Volume:
Article:
×